SourceText

Struct SourceText 

pub struct SourceText { /* private fields */ }
A type representing a single identifier that may be referred to by [Span]s.

In most cases, an identifier is a single input file.

Implementations

Source

impl SourceText

pub fn snippet<S, N>(text: S, name: N) -> Self
where S: Into<String>, N: Into<Cow<'static, str>>,

Create a snippet with given name

pub fn source_id(&self) -> SourceID

Get the cache id

pub fn get_length(&self) -> usize

Get the length of the total number of characters in the identifier.

pub fn get_line(&self, idx: usize) -> Option<&SourceLine>

Get access to a specific, zero-indexed SourceLine.

pub fn get_source(&self) -> &SourcePath

Get the length of the total number of characters in the identifier.

pub fn set_source(&mut self, path: SourcePath)

Set path name of identifier

pub fn set_path(&mut self, path: &Path)

Set path name of identifier

pub fn with_path(self, path: &Path) -> Self

Get path name of identifier

pub fn set_remote(&mut self, url: Url) -> bool

Set path name of identifier

pub fn with_remote(self, url: Url) -> Self

Get path name of identifier

pub fn text(&self) -> &str

Return the raw text fetch from source

pub fn lines(&self) -> &[SourceLine]

Return an iterator over the SourceLines in this identifier.

pub fn clear(&mut self)

Clear the cache cache

Source

impl SourceText

pub fn get_offset_line(&self, offset: u32) -> Option<(&SourceLine, usize, u32)>

Get the line that the given offset appears on, and the line/column numbers of the offset.

Note that the line/column numbers are zero-indexed.

pub fn get_line_range(&self, span: &Range<u32>) -> Range<usize>

Get the range of lines that this source_text runs across.

The resulting range is guaranteed to contain valid line indices (i.e: those that can be used for SourceText::get_line).